'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useDidMount = require('./useDidMount.js');
var useMutationObserver = require('./useMutationObserver.js');

/**
 * @param element HTML element whose boundingclientrect is needed
 * @returns DOMRect
 */
function getBoundingClientRect(element) {
    return element.getBoundingClientRect();
}
/**
 * useBoundingclientRect hook
 *
 * @param ref The React ref whose ClientRect is needed
 * @returns DOMRect | null
 * @see https://rooks.vercel.app/docs/useBoundingclientRect
 */
function useBoundingclientrect(ref) {
    const [domRect, setDomRect] = react.useState(null);
    const update = react.useCallback(() => {
        setDomRect(ref.current ? getBoundingClientRect(ref.current) : null);
    }, [ref]);
    useDidMount.useDidMount(() => {
        update();
    });
    useMutationObserver.useMutationObserver(ref, update);
    return domRect;
}

exports.useBoundingclientrect = useBoundingclientrect;
