'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var debounce = require('lodash.debounce');
var react = require('react');
var useFreshRef = require('./useFreshRef.js');
var useWillUnmount = require('./useWillUnmount.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var debounce__default = /*#__PURE__*/_interopDefaultLegacy(debounce);

/**
 * Debounce hook
 * Debounces a function
 *
 * @param callback The callback to debounce
 * @param wait The duration to debounce
 * @param options The options object.
 * @param options.leading Specify invoking on the leading edge of the timeout.
 * @param options.maxWait The maximum time func is allowed to be delayed before it’s invoked.
 * @param options.trailing Specify invoking on the trailing edge of the timeout.
 * @returns Returns the new debounced function.
 * @see https://rooks.vercel.app/docs/useDebounce
 */
function useDebounce(callback, wait, options) {
    const createDebouncedCallback = react.useCallback((function_) => {
        return debounce__default["default"](function_, wait, options);
    }, [wait, options]);
    const freshCallback = useFreshRef.useFreshRef(callback);
    function tick(...args) {
        var _a;
        (_a = freshCallback.current) === null || _a === void 0 ? void 0 : _a.call(freshCallback, ...args);
    }
    const debouncedCallbackRef = react.useRef(createDebouncedCallback(tick));
    useWillUnmount.useWillUnmount(() => {
        var _a;
        return (_a = debouncedCallbackRef.current) === null || _a === void 0 ? void 0 : _a.cancel();
    });
    return debouncedCallbackRef.current;
}

exports.useDebounce = useDebounce;
