'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var useGlobalObjectEventListener = require('./useGlobalObjectEventListener.js');

/**
 *  useDocumentEventListener hook
 *
 * @description A react hook to an event listener to the document
 *
 * @param {keyof DocumentEventMap} eventName The event to track
 * @param {Function} callback The callback to be called on event
 * @param {ListenerOptions} listenerOptions The options to be passed to the event listener
 * @param {boolean} isLayoutEffect Should it use layout effect. Defaults to false
 * @see https://rooks.vercel.app/docs/useDocumentEventListener
 */
function useDocumentEventListener(eventName, callback, listenerOptions = {}, isLayoutEffect = false) {
    useGlobalObjectEventListener.useGlobalObjectEventListener(global.document, eventName, callback, listenerOptions, true, isLayoutEffect);
}

exports.useDocumentEventListener = useDocumentEventListener;
