'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useGlobalObjectEventListener = require('./useGlobalObjectEventListener.js');

/**
 * useDocumentVisibilityState
 * @description Returns the visibility state of the document. Returns null on the server side.
 * @returns {UseDocumentVisibilityStateReturnType} The visibility state of the document. `null` on the server.
 * @see {@link https://rooks.vercel.app/docs/useDocumentVisibilityState}
 */
function useDocumentVisibilityState() {
    const [visibilityState, setVisibilityState] = react.useState(document ? document.visibilityState : null);
    const handleVisibilityChange = react.useCallback(() => {
        setVisibilityState(document ? document.visibilityState : null);
    }, []);
    useGlobalObjectEventListener.useGlobalObjectEventListener(global.document, "visibilitychange", handleVisibilityChange, {}, true, true);
    return visibilityState;
}

exports.useDocumentVisibilityState = useDocumentVisibilityState;
