'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useFreshRef = require('./useFreshRef.js');

/**
 * useFreshCallback
 * @description Avoid stale closures and keep your callback fresh
 * @see {@link https://rooks.vercel.app/docs/useFreshCallback}
 */
/**
 * useFreshCallback
 * @param callback Any callback function
 * @returns A fresh callback.
 * @see https://rooks.vercel.app/docs/useFreshCallback
 */
function useFreshCallback(callback) {
    const freshRef = useFreshRef.useFreshRef(callback);
    const tick = react.useCallback((...args) => {
        return freshRef.current(...args);
    }, [freshRef]);
    return tick;
}

exports.useFreshCallback = useFreshCallback;
