'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

/**
 * @description useGetIsMounted hook checks if a component is mounted or not at the time.
 * Useful for async effects. Returns a callback that returns a boolean representing if the component
 * is mounted at the time.
 * @returns () => boolean
 * @see https://rooks.vercel.app/docs/useGetIsMounted
 */
const useGetIsMounted = () => {
    const isMountedRef = react.useRef(false);
    const get = react.useCallback(() => isMountedRef.current, []);
    react.useEffect(() => {
        isMountedRef.current = true;
        return () => {
            isMountedRef.current = false;
        };
    }, []);
    return get;
};

exports.useGetIsMounted = useGetIsMounted;
