'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

/**
 * useOrientation
 * @description orientation hook for react
 * @see {@link https://rooks.vercel.app/docs/useOrientation}
 */
const useOrientation = () => {
    const [orientation, setOrientation] = react.useState(typeof window !== "undefined" ? window.screen.orientation : null);
    react.useEffect(() => {
        const handleOrientationChange = () => {
            setOrientation(window.screen.orientation);
        };
        window.screen.orientation.addEventListener("change", handleOrientationChange);
        return () => {
            window.screen.orientation.removeEventListener("change", handleOrientationChange);
        };
    }, []);
    return orientation;
};

exports.useOrientation = useOrientation;
