'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var noop = require('../utils/noop.js');
var react = require('react');

const config = {
    box: "content-box",
};
/**
 *
 * useResizeObserverRef hook
 *
 * Returns a resize observer for a React Ref and fires a callback
 * https://developer.mozilla.org/en-US/docs/Web/API/ResizeObserver
 *
 * @param {ResizeObserverCallback} callback Function that needs to be fired on resize
 * @param {ResizeObserverOptions} options An options object allowing you to set options for the observation
 * @returns {[CallbackRef]} callbackref
 * @see https://rooks.vercel.app/docs/useResizeObserverRef
 */
function useResizeObserverRef(callback, options = config) {
    const { box } = options;
    const [node, setNode] = react.useState(null);
    const callbackRef = react.useRef(callback);
    react.useEffect(() => {
        callbackRef.current = callback;
    });
    const handleResizeObserver = react.useCallback((...args) => {
        var _a;
        (_a = callbackRef.current) === null || _a === void 0 ? void 0 : _a.call(callbackRef, ...args);
    }, []);
    react.useEffect(() => {
        if (node) {
            // Create an observer instance linked to the callback function
            const observer = new ResizeObserver(handleResizeObserver);
            // Start observing the target node for resizes
            observer.observe(node, { box });
            return () => {
                observer.disconnect();
            };
        }
        return noop.noop;
    }, [node, handleResizeObserver, box]);
    const ref = react.useCallback((node) => {
        setNode(node);
    }, []);
    return [ref];
}

exports.useResizeObserverRef = useResizeObserverRef;
