'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

/**
 * useVibrate
 * @description Vibration API hook for React
 * @see {@link https://rooks.vercel.app/docs/useVibrate}
 */
function useVibrate({ isEnabled, pattern }) {
    react.useEffect(() => {
        if (!("vibrate" in navigator) || typeof navigator.vibrate !== "function") {
            console.warn("Vibration API not supported by the current browser");
            return;
        }
        if (isEnabled) {
            navigator.vibrate(pattern);
        }
        else {
            navigator.vibrate(0);
        }
        return () => {
            navigator.vibrate(0);
        };
    }, [isEnabled, pattern]);
}

exports.useVibrate = useVibrate;
