'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var useOnWindowResize = require('./useOnWindowResize.js');
var useOnWindowScroll = require('./useOnWindowScroll.js');

function computeScrollPosition() {
    if (typeof window === "undefined") {
        return {
            scrollX: 0,
            scrollY: 0,
        };
    }
    else {
        return {
            scrollX: window.scrollX || window.pageXOffset,
            scrollY: window.scrollY || window.pageYOffset,
        };
    }
}
/**
 *
 * useWindowScrollPosition hook
 * A React hook to get the scroll position of the window
 *
 * @returns an object containing scrollX and scrollY values
 * @see https://rooks.vercel.app/docs/useWindowScrollPosition
 */
function useWindowScrollPosition() {
    const [scrollPosition, setScrollPosition] = react.useState(computeScrollPosition);
    /**
     * Recalculate on scroll
     */
    useOnWindowScroll.useOnWindowScroll(() => {
        setScrollPosition(computeScrollPosition());
    }, true, true);
    /**
     * Recalculate on resize
     */
    useOnWindowResize.useOnWindowResize(() => {
        setScrollPosition(computeScrollPosition());
    }, true, true);
    return scrollPosition;
}

exports.useWindowScrollPosition = useWindowScrollPosition;
