import { useState } from 'react';
import { useWindowEventListener } from './useWindowEventListener.js';

function getLanguage() {
    // eslint-disable-next-line no-negated-condition
    if (typeof navigator !== "undefined") {
        // eslint-disable-next-line @typescript-eslint/dot-notation
        return navigator.language;
    }
    else {
        return null;
    }
}
/**
 * useNavigatorLanguage hook
 * Returns the language of the navigator
 *
 * @returns {Language}
 * @see https://rooks.vercel.app/docs/useNavigatorLanguage
 */
function useNavigatorLanguage() {
    const [language, setLanguage] = useState(getLanguage);
    useWindowEventListener("languagechange", () => {
        setLanguage(getLanguage);
    });
    return language;
}

export { useNavigatorLanguage };
