import { useState, useEffect } from 'react';

/**
 * useOrientation
 * @description orientation hook for react
 * @see {@link https://rooks.vercel.app/docs/useOrientation}
 */
const useOrientation = () => {
    const [orientation, setOrientation] = useState(typeof window !== "undefined" ? window.screen.orientation : null);
    useEffect(() => {
        const handleOrientationChange = () => {
            setOrientation(window.screen.orientation);
        };
        window.screen.orientation.addEventListener("change", handleOrientationChange);
        return () => {
            window.screen.orientation.removeEventListener("change", handleOrientationChange);
        };
    }, []);
    return orientation;
};

export { useOrientation };
