import raf from 'raf';
import { useRef, useEffect } from 'react';
import { noop } from '../utils/noop.js';

/**
 *
 * useRaf
 * Uses a polyfilled version of requestAnimationFrame
 *
 * @param {Function} callback The callback function to be executed
 * @param {boolean} [isActive] The value which while true, keeps the raf running infinitely
 * @see https://rooks.vercel.app/docs/useRaf
 */
function useRaf(callback, isActive) {
    const savedCallback = useRef();
    // Remember the latest function.
    useEffect(() => {
        savedCallback.current = callback;
    }, [callback]);
    useEffect(() => {
        let animationFrame;
        let startTime = Date.now();
        function tick() {
            var _a;
            const timeElapsed = Date.now() - startTime;
            startTime = Date.now();
            loop();
            (_a = savedCallback.current) === null || _a === void 0 ? void 0 : _a.call(savedCallback, timeElapsed);
        }
        function loop() {
            animationFrame = raf(tick);
        }
        if (isActive) {
            startTime = Date.now();
            loop();
            return () => {
                if (animationFrame) {
                    raf.cancel(animationFrame);
                }
            };
        }
        else {
            return noop;
        }
    }, [isActive]);
}

export { useRaf };
