import { useEffect } from 'react';

/**
 * useVibrate
 * @description Vibration API hook for React
 * @see {@link https://rooks.vercel.app/docs/useVibrate}
 */
function useVibrate({ isEnabled, pattern }) {
    useEffect(() => {
        if (!("vibrate" in navigator) || typeof navigator.vibrate !== "function") {
            console.warn("Vibration API not supported by the current browser");
            return;
        }
        if (isEnabled) {
            navigator.vibrate(pattern);
        }
        else {
            navigator.vibrate(0);
        }
        return () => {
            navigator.vibrate(0);
        };
    }, [isEnabled, pattern]);
}

export { useVibrate };
